@@ -4,6 +4,7 @@ from datetime import datetime
 from tkinter.messagebox import showerror, askokcancel
 from tkinter import *
 from threading import Lock, Thread
+from inspect import isclass
 
 import os
 import logging
@@ -58,12 +59,14 @@ class LogHandle(object):
         for handler in logging.root.handlers[:]:
             logging.root.removeHandler(handler)
 
-    def gui_console(self, destroy=False, turn_off=False):
+    def gui_console(self, destroy=False, turn_off=False, gui_obj=None):
         if self.__gui_console and destroy:
             self.__gui_console.destroy()
             self.__gui_console = None
         elif self.__gui_console and turn_off:
             self.__gui_console = None
+        elif gui_obj and isclass(gui_obj) and hasattr(gui_obj, "print_gui"):
+            self.__gui_console = gui_obj
         else:
             self.__gui_console = GUIConsole()
 
