@@ -8,14 +8,14 @@ from pickle import dumps
 import os
 
 
-class KSG(Tk):
+class KSG(Toplevel):
     __pointer = None
 
-    def __init__(self, local_dir):
-        Tk.__init__(self)
+    def __init__(self, class_obj, local_dir):
+        Toplevel.__init__(self)
 
+        self.__class_obj = class_obj
         self.__local_dir = local_dir
-        self.__key_generated = False
         self.__salt_key_path = StringVar()
         self.__pepper_key_path = StringVar()
         self.__salt_key_dir = StringVar()
@@ -23,10 +23,6 @@ class KSG(Tk):
 
         self.__build()
 
-    @property
-    def key_generated(self):
-        return self.__key_generated
-
     def __build(self):
         header = ['Welcome to Salt & Pepper setup!', 'Please fill out the below fields to setup']
         header2 = ['Welcome to existing Salt & Pepper setup!', 'Please fill out the below fields to setup']
@@ -72,24 +68,24 @@ class KSG(Tk):
         # Apply Widgets to new_salt_frame
         #   Apply Salt Directory Entry Box Widget
         salt_dir_label = Label(new_salt_frame, text='Salt Dir:')
-        salt_dir_entry = Entry(new_salt_frame, textvariable=self.__salt_key_dir)
+        salt_dir_entry = Entry(new_salt_frame, width=23, textvariable=self.__salt_key_dir)
         salt_dir_label.grid(row=0, column=0, padx=4, pady=5)
-        salt_dir_entry.grid(row=0, column=1, padx=4, pady=5)
+        salt_dir_entry.grid(row=0, column=1, padx=20, pady=5)
 
         #   Apply Salt Directory Finder Button Widget
-        find_salt_dir_button = Button(new_salt_frame, text='...', width=8, command=self.__salt_dir_gui)
-        find_salt_dir_button.grid(row=0, column=2, padx=4, pady=5)
+        find_salt_dir_button = Button(new_salt_frame, text='...', width=2, command=self.__salt_dir_gui)
+        find_salt_dir_button.grid(row=0, column=2, padx=0, pady=5)
 
         # Apply Widgets to new_settings_frame
         #    Apply Pepper Directory Entry Box Widget
         pepper_dir_label = Label(new_pepper_frame, text='Pepper Dir:')
-        pepper_dir_entry = Entry(new_pepper_frame, textvariable=self.__pepper_key_dir)
+        pepper_dir_entry = Entry(new_pepper_frame, width=23, textvariable=self.__pepper_key_dir)
         pepper_dir_label.grid(row=0, column=0, padx=4, pady=5)
         pepper_dir_entry.grid(row=0, column=1, padx=4, pady=5)
 
         #   Apply Pepper Directory Finder Button Widget
-        find_pepper_dir_button = Button(new_pepper_frame, text='...', width=8, command=self.__pepper_dir_gui)
-        find_pepper_dir_button.grid(row=0, column=2, padx=4, pady=5)
+        find_pepper_dir_button = Button(new_pepper_frame, text='...', width=2, command=self.__pepper_dir_gui)
+        find_pepper_dir_button.grid(row=0, column=2, padx=15, pady=5)
 
         # Apply Buttons to the new_buttons_frame
         #     Generate button
@@ -103,28 +99,28 @@ class KSG(Tk):
         # Apply Widgets to existing_frame
         #   Apply Salt Directory Entry Box Widget
         salt_fp_label = Label(existing_salt_frame, text='Salt FP:')
-        salt_fp_entry = Entry(existing_salt_frame, textvariable=self.__salt_key_path)
+        salt_fp_entry = Entry(existing_salt_frame, width=23, textvariable=self.__salt_key_path)
         salt_fp_label.grid(row=0, column=0, padx=4, pady=5)
-        salt_fp_entry.grid(row=0, column=1, padx=4, pady=5)
+        salt_fp_entry.grid(row=0, column=1, padx=20, pady=5)
 
         #   Apply Salt File Name Finder Button Widget
-        find_salt_name_button = Button(existing_salt_frame, text='...', width=8, command=self.__salt_file_gui)
-        find_salt_name_button.grid(row=0, column=2, padx=4, pady=5)
+        find_salt_name_button = Button(existing_salt_frame, text='...', width=2, command=self.__salt_file_gui)
+        find_salt_name_button.grid(row=0, column=2, padx=0, pady=5)
 
         #   Apply Main Filepath Entry Box Widget
         pepper_fp_label = Label(existing_pepper_frame, text='Pepper FP:')
-        pepper_fp_entry = Entry(existing_pepper_frame, textvariable=self.__pepper_path)
+        pepper_fp_entry = Entry(existing_pepper_frame, width=23, textvariable=self.__pepper_key_path)
         pepper_fp_label.grid(row=1, column=0, padx=4, pady=5)
         pepper_fp_entry.grid(row=1, column=1, padx=4, pady=5)
 
         #   Apply Main Filepath Finder Button Widget
-        find_pepper_fp_button = Button(existing_pepper_frame, text='...', width=3, command=self.__pepper_fp_gui)
-        find_pepper_fp_button.grid(row=1, column=2, padx=4, pady=5)
+        find_pepper_fp_button = Button(existing_pepper_frame, text='...', width=2, command=self.__pepper_file_gui)
+        find_pepper_fp_button.grid(row=1, column=2, padx=15, pady=5)
 
         # Apply Buttons to the existing_buttons_frame
         #     Generate button
-        generate_button = Button(self, text='Generate', width=15, command=self.__generate2)
-        generate_button.pack(in_=existing_buttons_frame, side=LEFT, padx=7, pady=7)
+        link_file_button = Button(self, text='Link File', width=15, command=self.__link_file)
+        link_file_button.pack(in_=existing_buttons_frame, side=LEFT, padx=7, pady=7)
 
         #     Cancel button
         cancel_button = Button(self, text='Cancel', width=15, command=self.destroy)
@@ -184,7 +180,7 @@ class KSG(Tk):
             self.__pepper_key_path.set(settings_name.name)
             settings_name.close()
 
-    def __generate2(self):
+    def __link_file(self):
         from . import default_key_dir
         key_dir = default_key_dir()
 
@@ -200,19 +196,22 @@ class KSG(Tk):
             showerror('Path Exist Error!', 'Salt Key Path does not exist!', parent=self)
         elif not os.path.exists(self.__pepper_key_path.get()):
             showerror('Path Exist Error!', 'Pepper Key Path does not exist!', parent=self)
-        elif os.path.dirname(self.salt_key_path.get()).lower() == key_dir.lower():
+        elif os.path.dirname(self.__salt_key_path.get()).lower() == key_dir.lower():
             showerror('Default Path Error!', 'No need to point to default path for Salt Key!', parent=self)
-        elif os.path.dirname(self.pepper_key_path.get()).lower() == key_dir.lower():
+        elif os.path.dirname(self.__pepper_key_path.get()).lower() == key_dir.lower():
             showerror('Default Path Error!', 'No need to point to default path for Pepper Key!', parent=self)
         else:
             from .data import file_write_bytes, KeyPtr
 
-            key_ptr_fp = os.path.join(key_dir, "Key.dir")
-            key_ptr = KeyPtr(salt_key_fp=self.salt_key_path.get(), pepper_key_fp=self.pepper_key_path.get())
-            file_write_bytes(key_ptr_fp, dumps(key_ptr))
-            self.__key_generated = True
+            if not os.path.exists(key_dir):
+                os.mkdir(key_dir)
 
-            self.destroy()
+            key_ptr_fp = os.path.join(key_dir, "Key.dir")
+            key_ptr = KeyPtr(salt_key_fp=self.__salt_key_path.get(), pepper_key_fp=self.__pepper_key_path.get())
+            file_write_bytes(file_path=key_ptr_fp, data=dumps(key_ptr))
+            self.__class_obj.key_generated = True
+
+            self.__class_obj.destroy()
 
     def __generate(self):
         if not self.__salt_key_dir:
@@ -228,10 +227,14 @@ class KSG(Tk):
         elif not os.path.exists(self.__pepper_key_dir.get()):
             showerror('Directory Not Exist!', 'Pepper Key Directory does not exist', parent=self)
         else:
-            from .data import create_key
+            from .data import create_key, file_write_bytes, KeyPtr
             from . import default_key_dir
 
             key_dir = default_key_dir()
+
+            if not os.path.exists(key_dir):
+                os.mkdir(key_dir)
+
             key_ptr_fp = os.path.join(key_dir, "Key.dir")
             salt_key_fp = os.path.join(self.__salt_key_dir.get(), "Salt.key")
             pepper_key_fp = os.path.join(self.__pepper_key_dir.get(), "Pepper.key")
@@ -239,9 +242,9 @@ class KSG(Tk):
             create_key(self.__pepper_key_dir.get(), "Pepper.key")
             key_ptr = KeyPtr(salt_key_fp=salt_key_fp, pepper_key_fp=pepper_key_fp)
             file_write_bytes(key_ptr_fp, dumps(key_ptr))
-            self.__key_generated = True
+            self.__class_obj.key_generated = True
 
-            self.destroy()
+            self.__class_obj.destroy()
 
 
 class KeySetupGUI(KSG):
@@ -249,12 +252,11 @@ class KeySetupGUI(KSG):
     Setup GUI for Salt Key, Main DB, Local DB, and Pointer files
     """
 
-    def __init__(self, local_dir=None):
-        KSG.__init__(self, local_dir=local_dir)
-        self.mainloop()
+    def __init__(self, class_obj, local_dir=None):
+        KSG.__init__(self, class_obj, local_dir=local_dir)
 
 
-class KSG(Tk):
+class DKSG(Tk):
     __pointer = None
 
     def __init__(self, local_dir):
@@ -270,19 +272,22 @@ class KSG(Tk):
     def key_generated(self):
         return self.__key_generated
 
+    @key_generated.setter
+    def key_generated(self, key_generated):
+        self.__key_generated = key_generated
+
     def __build(self):
         header = ['Welcome to Salt & Pepper setup!', 'Would you like to install in default location?']
 
         # Set GUI Geometry and GUI Title
-        self.geometry('280x135+550+150')
+        self.geometry('280x80+550+150')
         self.title('Salt & Pepper Setup')
         self.resizable(False, False)
 
-        new_header_frame = Frame(new_tab)
-        new_buttons_frame = Frame(new_tab)
+        new_header_frame = Frame(self)
+        new_buttons_frame = Frame(self)
 
         # Apply Frames into GUI
-        t.pack(fill="both")
         new_header_frame.pack(fill="both")
         new_buttons_frame.pack(fill="both")
 
@@ -302,6 +307,7 @@ class KSG(Tk):
     def __default(self):
         if not self.__specific_obj:
             from . import default_key_dir
+            from .data import create_key
             key_dir = default_key_dir()
 
             create_key(key_dir, "Salt.key")
@@ -310,9 +316,7 @@ class KSG(Tk):
             self.destroy()
 
     def __specific(self):
-        self.__specific_obj = KeySetupGUI(self.__local_dir)
-        self.__key_generated = self.__specific_obj.key_generated
-        self.destroy()
+        self.__specific_obj = KeySetupGUI(class_obj=self, local_dir=self.__local_dir)
 
 
 class DefaultKeySetupGUI(DKSG):
@@ -367,7 +371,7 @@ class MDG(Tk):
         header2 = ['Welcome to existing main database setup!', 'Please fill out the below fields to setup']
 
         # Set GUI Geometry and GUI Title
-        self.geometry('280x135+550+150')
+        self.geometry('280x160+550+150')
         self.title('Main Database Setup')
         self.resizable(False, False)
 
@@ -527,8 +531,6 @@ class MainDatabaseGUI(MDG):
         """
         :param local_db_dir:  Local DB directory (aka local script directory)
         :param main_db_path: (Optional) Main DB filepath
-        :param pepper_key_path (Optional) Pepper Key filepath
-        :param salt_key_path: (Optional) Salt Key filepath
         :param pointer: (Optional) Pointer .ptr DataConfig instance class
         """
 
